@@ -43,17 +43,17 @@ SV_IMPL_PTRARR(SvxEntryLst, SvxBoxEntry*)
 
 SvxBoxEntry::SvxBoxEntry() :
     nId(LISTBOX_ENTRY_NOTFOUND),
-    bModified(FALSE),
-    bNew(FALSE)
+    bModified(sal_False),
+    bNew(sal_False)
 {
 }
 
 
-SvxBoxEntry::SvxBoxEntry(const String& aNam, USHORT nIdx) :
+SvxBoxEntry::SvxBoxEntry(const String& aNam, sal_uInt16 nIdx) :
     aName(aNam),
     nId(nIdx),
-    bModified(FALSE),
-    bNew(FALSE)
+    bModified(sal_False),
+    bNew(sal_False)
 {
 }
 
@@ -66,10 +66,6 @@ SvxBoxEntry::SvxBoxEntry(const SvxBoxEntry& rOld) :
 {
 }
 
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
 SvxListBox::SvxListBox(Window* pParent, WinBits nBits) :
     ListBox(pParent, nBits)
 {
@@ -87,7 +83,7 @@ SvxListBox::SvxListBox(Window* pParent, const ResId& rId):
      Beschreibung: Basisklasse Dtor
  --------------------------------------------------------------------*/
 
-__EXPORT SvxListBox::~SvxListBox()
+SvxListBox::~SvxListBox()
 {
     aEntryLst.DeleteAndDestroy(0,	aEntryLst.Count());
     aDelEntryLst.DeleteAndDestroy(0, aDelEntryLst.Count());
@@ -100,8 +96,8 @@ __EXPORT SvxListBox::~SvxListBox()
 void SvxListBox::InitListBox()
 {
     // Verwaltung fuer die Stringlist aus der Resource aufbauen
-    USHORT nSize = GetEntryCount();
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nSize = GetEntryCount();
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	const SvxBoxEntry* pTmp = new SvxBoxEntry(ListBox::GetEntry(i), i);
         const SvxBoxEntry* &rpTmp = pTmp;
         aEntryLst.Insert(rpTmp, aEntryLst.Count());
@@ -115,7 +111,7 @@ void SvxListBox::InitListBox()
 void SvxListBox::InsertNewEntry(const SvxBoxEntry& rEntry)
 {
     SvxBoxEntry* pNew = new SvxBoxEntry(rEntry);
-    pNew->bNew = TRUE;
+    pNew->bNew = sal_True;
     InsertSorted(pNew);
 }
 
@@ -123,7 +119,7 @@ void SvxListBox::InsertNewEntry(const SvxBoxEntry& rEntry)
      Beschreibung: Eintrag in die ListBox aufnehmen
  --------------------------------------------------------------------*/
 
-void SvxListBox::InsertEntry(const SvxBoxEntry& rEntry, USHORT nPos)
+void SvxListBox::InsertEntry(const SvxBoxEntry& rEntry, sal_uInt16 nPos)
 {
     if(nPos != LISTBOX_ENTRY_NOTFOUND)
     {
@@ -140,7 +136,7 @@ void SvxListBox::InsertEntry(const SvxBoxEntry& rEntry, USHORT nPos)
      Beschreibung: Eintrag aus der Liste loeschen
  --------------------------------------------------------------------*/
 
-void SvxListBox::RemoveEntry(USHORT nPos)
+void SvxListBox::RemoveEntry(sal_uInt16 nPos)
 {
     if(nPos >= aEntryLst.Count())
         return;
@@ -164,7 +160,7 @@ void SvxListBox::RemoveEntry(USHORT nPos)
 
 void SvxListBox::RemoveEntry(const SvxBoxEntry& rEntry)
 {
-    USHORT nPos = ListBox::GetEntryPos(rEntry.aName);
+    sal_uInt16 nPos = ListBox::GetEntryPos(rEntry.aName);
     RemoveEntry(nPos);
 }
 
@@ -183,7 +179,7 @@ void SvxListBox::Clear()
      Beschreibung: Position by Name
  --------------------------------------------------------------------*/
 
-USHORT SvxListBox::GetEntryPos(const SvxBoxEntry& rEntry) const
+sal_uInt16 SvxListBox::GetEntryPos(const SvxBoxEntry& rEntry) const
 {
     return ListBox::GetEntryPos(rEntry.aName);
 }
@@ -192,7 +188,7 @@ USHORT SvxListBox::GetEntryPos(const SvxBoxEntry& rEntry) const
      Beschreibung: Rund um die Entries
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxListBox::GetSvxBoxEntry(USHORT nPos) const
+const SvxBoxEntry& SvxListBox::GetSvxBoxEntry(sal_uInt16 nPos) const
 {
     if(nPos < aEntryLst.Count())
         return *aEntryLst[nPos];
@@ -204,13 +200,13 @@ const SvxBoxEntry& SvxListBox::GetSvxBoxEntry(USHORT nPos) const
      Beschreibung: aktullen Eintrag zurueckgeben
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxListBox::GetSelectSvxBoxEntry(USHORT nSelId) const
+const SvxBoxEntry& SvxListBox::GetSelectSvxBoxEntry(sal_uInt16 nSelId) const
 {
     String aName(ListBox::GetSelectEntry(nSelId));
 
     if(aName.Len() > 0)
     {
-        for (USHORT i=0; i < aEntryLst.Count(); i++)
+        for (sal_uInt16 i=0; i < aEntryLst.Count(); i++)
         {
             if(aEntryLst[i]->aName == aName )
                 return *aEntryLst[i];
@@ -223,11 +219,11 @@ const SvxBoxEntry& SvxListBox::GetSelectSvxBoxEntry(USHORT nSelId) const
      Beschreibung: modifizierte Eintraege
  --------------------------------------------------------------------*/
 
-USHORT SvxListBox::GetModifiedCount() const
+sal_uInt16 SvxListBox::GetModifiedCount() const
 {
-    USHORT nMod  = 0;
-    USHORT nSize = aEntryLst.Count();
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nMod  = 0;
+    sal_uInt16 nSize = aEntryLst.Count();
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bModified)
             nMod++;
     }
@@ -238,7 +234,7 @@ USHORT SvxListBox::GetModifiedCount() const
      Beschreibung: Modifizierte Eintraege behandeln
  --------------------------------------------------------------------*/
 
-void SvxListBox::ModifyEntry(USHORT nPos, const String& rName)
+void SvxListBox::ModifyEntry(sal_uInt16 nPos, const String& rName)
 {
     if(nPos >= aEntryLst.Count())
         return;
@@ -246,7 +242,7 @@ void SvxListBox::ModifyEntry(USHORT nPos, const String& rName)
     SvxBoxEntry* pEntry = aEntryLst[nPos];
     aEntryLst.Remove(nPos, 1);
     aEntryLst[nPos]->aName 		= rName;
-    aEntryLst[nPos]->bModified 	= TRUE;
+    aEntryLst[nPos]->bModified 	= sal_True;
     ListBox::RemoveEntry(nPos);
 
     InsertSorted(pEntry);
@@ -256,11 +252,11 @@ void SvxListBox::ModifyEntry(USHORT nPos, const String& rName)
      Beschreibung: alle modifizierten Eintraege bahandeln
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxListBox::GetModifiedEntry(USHORT nPos) const
+const SvxBoxEntry& SvxListBox::GetModifiedEntry(sal_uInt16 nPos) const
 {
-    USHORT nSize = aEntryLst.Count();
-    USHORT nMod  = 0;
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nSize = aEntryLst.Count();
+    sal_uInt16 nMod  = 0;
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bModified)
         {	if(nMod == nPos)
                 return *aEntryLst[i];
@@ -274,13 +270,13 @@ const SvxBoxEntry& SvxListBox::GetModifiedEntry(USHORT nPos) const
      Beschreibung: geloeschte Eintraege
  --------------------------------------------------------------------*/
 
-USHORT SvxListBox::GetRemovedCount() const
+sal_uInt16 SvxListBox::GetRemovedCount() const
 {
     return aDelEntryLst.Count();
 }
 
 
-const SvxBoxEntry& SvxListBox::GetRemovedEntry(USHORT nPos) const
+const SvxBoxEntry& SvxListBox::GetRemovedEntry(sal_uInt16 nPos) const
 {
     if(nPos < aDelEntryLst.Count())
         return *aDelEntryLst[nPos];
@@ -292,11 +288,11 @@ const SvxBoxEntry& SvxListBox::GetRemovedEntry(USHORT nPos) const
      Beschreibung: Neue Entries begutachten
  --------------------------------------------------------------------*/
 
-USHORT SvxListBox::GetNewCount() const
+sal_uInt16 SvxListBox::GetNewCount() const
 {
-    USHORT nNew = 0;
-    USHORT nSize = aEntryLst.Count();
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nNew = 0;
+    sal_uInt16 nSize = aEntryLst.Count();
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bNew)
             nNew++;
     }
@@ -307,11 +303,11 @@ USHORT SvxListBox::GetNewCount() const
      Beschreibung:	Alle neuen Eintraege ueberpruefen
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxListBox::GetNewEntry(USHORT nPos) const
+const SvxBoxEntry& SvxListBox::GetNewEntry(sal_uInt16 nPos) const
 {
-    USHORT nSize = aEntryLst.Count();
-    USHORT nNew  = 0;
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nSize = aEntryLst.Count();
+    sal_uInt16 nNew  = 0;
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bNew)
         {	if(nNew == nPos)
                 return *aEntryLst[i];
@@ -328,7 +324,7 @@ const SvxBoxEntry& SvxListBox::GetNewEntry(USHORT nPos) const
 void SvxListBox::InsertSorted(SvxBoxEntry* pEntry)
 {
     ListBox::InsertEntry(pEntry->aName);
-    USHORT nPos = ListBox::GetEntryPos(pEntry->aName);
+    sal_uInt16 nPos = ListBox::GetEntryPos(pEntry->aName);
     aEntryLst.C40_INSERT(SvxBoxEntry, pEntry, nPos);
 }
 
@@ -336,7 +332,7 @@ void SvxListBox::InsertSorted(SvxBoxEntry* pEntry)
      Beschreibung: ComboBoxen mit Verwaltungseinheit
  --------------------------------------------------------------------*/
 
-SvxComboBox::SvxComboBox(Window* pParent, WinBits nBits, USHORT nStyleBits) :
+SvxComboBox::SvxComboBox(Window* pParent, WinBits nBits, sal_uInt16 nStyleBits) :
     ComboBox(pParent, nBits),
     nStyle(nStyleBits)
 {
@@ -344,7 +340,7 @@ SvxComboBox::SvxComboBox(Window* pParent, WinBits nBits, USHORT nStyleBits) :
 }
 
 
-SvxComboBox::SvxComboBox(Window* pParent, const ResId& rId, USHORT nStyleBits ):
+SvxComboBox::SvxComboBox(Window* pParent, const ResId& rId, sal_uInt16 nStyleBits ):
     ComboBox(pParent, rId),
     nStyle(nStyleBits)
 {
@@ -355,7 +351,7 @@ SvxComboBox::SvxComboBox(Window* pParent, const ResId& rId, USHORT nStyleBits ):
      Beschreibung: Basisklasse Dtor
  --------------------------------------------------------------------*/
 
-__EXPORT SvxComboBox::~SvxComboBox()
+SvxComboBox::~SvxComboBox()
 {
     aEntryLst.DeleteAndDestroy(0,	aEntryLst.Count());
     aDelEntryLst.DeleteAndDestroy(0, aDelEntryLst.Count());
@@ -368,8 +364,8 @@ __EXPORT SvxComboBox::~SvxComboBox()
 void SvxComboBox::InitComboBox()
 {
     // Verwaltung fuer die Stringlist aus der Resource aufbauen
-    USHORT nSize = GetEntryCount();
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nSize = GetEntryCount();
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	const SvxBoxEntry* pTmp = new SvxBoxEntry(ComboBox::GetEntry(i), i);
         const SvxBoxEntry* &rpTmp = pTmp;
         aEntryLst.Insert(rpTmp, aEntryLst.Count());
@@ -383,7 +379,7 @@ void SvxComboBox::InitComboBox()
 void SvxComboBox::InsertNewEntry(const SvxBoxEntry& rEntry)
 {
     SvxBoxEntry* pNew = new SvxBoxEntry(rEntry);
-    pNew->bNew = TRUE;
+    pNew->bNew = sal_True;
     InsertSorted(pNew);
 }
 
@@ -400,7 +396,7 @@ void SvxComboBox::InsertEntry(const SvxBoxEntry& rEntry)
      Beschreibung: Eintrag aus der Liste loeschen
  --------------------------------------------------------------------*/
 
-void SvxComboBox::RemoveEntry(USHORT nPos)
+void SvxComboBox::RemoveEntry(sal_uInt16 nPos)
 {
     if(nPos >= aEntryLst.Count())
         return;
@@ -424,7 +420,7 @@ void SvxComboBox::RemoveEntry(USHORT nPos)
 
 void SvxComboBox::RemoveEntry(const SvxBoxEntry& rEntry)
 {
-    USHORT nPos = ComboBox::GetEntryPos(rEntry.aName);
+    sal_uInt16 nPos = ComboBox::GetEntryPos(rEntry.aName);
     RemoveEntry(nPos);
 }
 
@@ -444,7 +440,7 @@ void SvxComboBox::Clear()
      Beschreibung: Position by Name
  --------------------------------------------------------------------*/
 
-USHORT SvxComboBox::GetEntryPos(const SvxBoxEntry& rEntry) const
+sal_uInt16 SvxComboBox::GetEntryPos(const SvxBoxEntry& rEntry) const
 {
     return ComboBox::GetEntryPos(rEntry.aName);
 }
@@ -453,7 +449,7 @@ USHORT SvxComboBox::GetEntryPos(const SvxBoxEntry& rEntry) const
      Beschreibung: Rund um die Entries
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxComboBox::GetEntry(USHORT nPos) const
+const SvxBoxEntry& SvxComboBox::GetEntry(sal_uInt16 nPos) const
 {
     if(nPos < aEntryLst.Count())
         return *aEntryLst[nPos];
@@ -465,11 +461,11 @@ const SvxBoxEntry& SvxComboBox::GetEntry(USHORT nPos) const
      Beschreibung: modifizierte Eintraege
  --------------------------------------------------------------------*/
 
-USHORT SvxComboBox::GetModifiedCount() const
+sal_uInt16 SvxComboBox::GetModifiedCount() const
 {
-    USHORT nMod  = 0;
-    USHORT nSize = aEntryLst.Count();
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nMod  = 0;
+    sal_uInt16 nSize = aEntryLst.Count();
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bModified)
             nMod++;
     }
@@ -480,7 +476,7 @@ USHORT SvxComboBox::GetModifiedCount() const
      Beschreibung: Modifizierte Eintraege behandeln
  --------------------------------------------------------------------*/
 
-void SvxComboBox::ModifyEntry(USHORT nPos, const String& rName)
+void SvxComboBox::ModifyEntry(sal_uInt16 nPos, const String& rName)
 {
     if(nPos >= aEntryLst.Count())
         return;
@@ -488,7 +484,7 @@ void SvxComboBox::ModifyEntry(USHORT nPos, const String& rName)
     SvxBoxEntry* pEntry = aEntryLst[nPos];
     aEntryLst.Remove(nPos, 1);
     aEntryLst[nPos]->aName 		= rName;
-    aEntryLst[nPos]->bModified 	= TRUE;
+    aEntryLst[nPos]->bModified 	= sal_True;
     ComboBox::RemoveEntry(nPos);
 
     InsertSorted(pEntry);
@@ -498,11 +494,11 @@ void SvxComboBox::ModifyEntry(USHORT nPos, const String& rName)
      Beschreibung: alle modifizierten Eintraege bahandeln
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxComboBox::GetModifiedEntry(USHORT nPos) const
+const SvxBoxEntry& SvxComboBox::GetModifiedEntry(sal_uInt16 nPos) const
 {
-    USHORT nSize = aEntryLst.Count();
-    USHORT nMod  = 0;
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nSize = aEntryLst.Count();
+    sal_uInt16 nMod  = 0;
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bModified)
         {	if(nMod == nPos)
                 return *aEntryLst[i];
@@ -516,13 +512,13 @@ const SvxBoxEntry& SvxComboBox::GetModifiedEntry(USHORT nPos) const
      Beschreibung: geloeschte Eintraege
  --------------------------------------------------------------------*/
 
-USHORT SvxComboBox::GetRemovedCount() const
+sal_uInt16 SvxComboBox::GetRemovedCount() const
 {
     return aDelEntryLst.Count();
 }
 
 
-const SvxBoxEntry& SvxComboBox::GetRemovedEntry(USHORT nPos) const
+const SvxBoxEntry& SvxComboBox::GetRemovedEntry(sal_uInt16 nPos) const
 {
     if(nPos < aDelEntryLst.Count())
         return *aDelEntryLst[nPos];
@@ -534,11 +530,11 @@ const SvxBoxEntry& SvxComboBox::GetRemovedEntry(USHORT nPos) const
      Beschreibung: Neue Entries begutachten
  --------------------------------------------------------------------*/
 
-USHORT SvxComboBox::GetNewCount() const
+sal_uInt16 SvxComboBox::GetNewCount() const
 {
-    USHORT nNew = 0;
-    USHORT nSize = aEntryLst.Count();
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nNew = 0;
+    sal_uInt16 nSize = aEntryLst.Count();
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bNew)
             nNew++;
     }
@@ -549,11 +545,11 @@ USHORT SvxComboBox::GetNewCount() const
      Beschreibung:	Alle neuen Eintraege ueberpruefen
  --------------------------------------------------------------------*/
 
-const SvxBoxEntry& SvxComboBox::GetNewEntry(USHORT nPos) const
+const SvxBoxEntry& SvxComboBox::GetNewEntry(sal_uInt16 nPos) const
 {
-    USHORT nSize = aEntryLst.Count();
-    USHORT nNew  = 0;
-    for(USHORT i=0; i < nSize; ++i)
+    sal_uInt16 nSize = aEntryLst.Count();
+    sal_uInt16 nNew  = 0;
+    for(sal_uInt16 i=0; i < nSize; ++i)
     {	if(aEntryLst[i]->bNew)
         {	if(nNew == nPos)
                 return *aEntryLst[i];
@@ -570,7 +566,7 @@ const SvxBoxEntry& SvxComboBox::GetNewEntry(USHORT nPos) const
 void SvxComboBox::InsertSorted(SvxBoxEntry* pEntry)
 {
     ComboBox::InsertEntry(pEntry->aName);
-    USHORT nPos = ComboBox::GetEntryPos(pEntry->aName);
+    sal_uInt16 nPos = ComboBox::GetEntryPos(pEntry->aName);
     aEntryLst.C40_INSERT(SvxBoxEntry, pEntry, nPos);
 }
 
@@ -579,7 +575,7 @@ void SvxComboBox::InsertSorted(SvxBoxEntry* pEntry)
     Beschreibung: Je nach Option bestimmte Zeichen ausblenden
  --------------------------------------------------------------------*/
 
-void __EXPORT SvxComboBox::KeyInput( const KeyEvent& rKEvt )
+void SvxComboBox::KeyInput( const KeyEvent& rKEvt )
 {
     sal_Unicode cChar = rKEvt.GetCharCode();
 
