@@ -34,7 +34,7 @@
 // include ---------------------------------------------------------------
 
 #include <svtools/insdlg.hxx>
-#include "sores.hxx"
+#include <svtools/sores.hxx>
 #include <svtools/svtdata.hxx>
 
 #include <tools/rc.hxx>
@@ -79,7 +79,7 @@ PRV_SV_IMPL_OWNER_LIST( SvObjectServerList, SvObjectServer )
 *************************************************************************/
 const SvObjectServer * SvObjectServerList::Get( const String & rHumanName ) const
 {
-    for( ULONG i = 0; i < Count(); i++ )
+    for( sal_uLong i = 0; i < Count(); i++ )
     {
         if( rHumanName == GetObject( i ).GetHumanName() )
             return &GetObject( i );
@@ -94,7 +94,7 @@ const SvObjectServer * SvObjectServerList::Get( const String & rHumanName ) cons
 *************************************************************************/
 const SvObjectServer * SvObjectServerList::Get( const SvGlobalName & rName ) const
 {
-    for( ULONG i = 0; i < Count(); i++ )
+    for( sal_uLong i = 0; i < Count(); i++ )
     {
         if( rName == GetObject( i ).GetClassName() )
             return &GetObject( i );
@@ -129,19 +129,17 @@ void SvObjectServerList::FillInsertObjects()
     uno::Reference< lang::XMultiServiceFactory > _globalMSFactory= comphelper::getProcessServiceFactory();
     if( _globalMSFactory.is())
     {
-        ::rtl::OUString sProviderService =
-        ::rtl::OUString::createFromAscii( "com.sun.star.configuration.ConfigurationProvider" );
+        ::rtl::OUString sProviderService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationProvider" ));
         uno::Reference< lang::XMultiServiceFactory > sProviderMSFactory(
             _globalMSFactory->createInstance( sProviderService ), uno::UNO_QUERY );
 
         if( sProviderMSFactory.is())
         {
-            ::rtl::OUString sReaderService =
-                ::rtl::OUString::createFromAscii( "com.sun.star.configuration.ConfigurationAccess" );
+            ::rtl::OUString sReaderService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationAccess" ));
             uno::Sequence< uno::Any > aArguments( 1 );
             beans::PropertyValue aPathProp;
-            aPathProp.Name = ::rtl::OUString::createFromAscii( "nodepath" );
-            aPathProp.Value <<= ::rtl::OUString::createFromAscii( "/org.openoffice.Office.Embedding/ObjectNames");
+            aPathProp.Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ));
+            aPathProp.Value <<= ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.Office.Embedding/ObjectNames" ));
             aArguments[0] <<= aPathProp;
 
             uno::Reference< container::XNameAccess > xNameAccess(
@@ -166,13 +164,13 @@ void SvObjectServerList::FillInsertObjects()
                     ::utl::ConfigManager::GetDirectConfigProperty( ::utl::ConfigManager::PRODUCTNAME );
                 if ( !( aProperty >>= aProductName ) )
                 {
-                    OSL_ENSURE( sal_False, "Coudn't get PRODUCTNAME variable!\n" );
+                    OSL_FAIL( "Coudn't get PRODUCTNAME variable!\n" );
                     aProductName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StarOffice" ) );
                 }
                 aProperty = ::utl::ConfigManager::GetDirectConfigProperty( ::utl::ConfigManager::PRODUCTVERSION );
                 if ( !( aProperty >>= aProductVersion ) )
                 {
-                    OSL_ENSURE( sal_False, "Coudn't get PRODUCTVERSION variable!\n" );
+                    OSL_FAIL( "Coudn't get PRODUCTVERSION variable!\n" );
                 }
 
                 for( nInd = 0; nInd < seqNames.getLength(); nInd++ )
@@ -183,8 +181,8 @@ void SvObjectServerList::FillInsertObjects()
                     {
                         ::rtl::OUString aUIName;
                         ::rtl::OUString aClassID;
-                        xEntry->getByName( ::rtl::OUString::createFromAscii("ObjectUIName") ) >>= aUIName;
-                        xEntry->getByName( ::rtl::OUString::createFromAscii("ClassID") ) >>= aClassID;
+                        xEntry->getByName( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ObjectUIName" )) ) >>= aUIName;
+                        xEntry->getByName( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ClassID" )) ) >>= aClassID;
 
                         if ( aUIName.getLength() )
                         {
@@ -240,7 +238,7 @@ String SvPasteObjectHelper::GetSotFormatUIName( SotFormatStringId nId )
     struct SotResourcePair
     {
         SotFormatStringId   mnSotId;
-        USHORT              mnResId;
+        sal_uInt16              mnResId;
     };
 
     static const SotResourcePair aSotResourcePairs[] =
@@ -314,7 +312,7 @@ String SvPasteObjectHelper::GetSotFormatUIName( SotFormatStringId nId )
     };
 
     String aUIName;
-    USHORT nResId = 0;
+    sal_uInt16 nResId = 0;
 
     for( sal_uInt32 i = 0, nCount = SAL_N_ELEMENTS( aSotResourcePairs ); ( i < nCount ) && !nResId; i++ )
     {
