@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,12 +33,10 @@
 
 extern "C"
 {
-    #define INT32 JPEG_INT32
     #include "stdio.h"
     #include "jpeg.h"
     #include "jpeglib.h"
     #include "jerror.h"
-    #undef INT32
 }
 
 #define _JPEGPRIVATE
@@ -125,7 +124,7 @@ extern "C" int empty_output_buffer (j_compress_ptr cinfo)
   dest->pub.next_output_byte = dest->buffer;
   dest->pub.free_in_buffer = BUF_SIZE;
 
-  return TRUE;
+  return sal_True;
 }
 
 extern "C" void term_destination (j_compress_ptr cinfo)
@@ -189,7 +188,7 @@ extern "C" void init_source (j_decompress_ptr cinfo)
    * but we don't clear the input buffer.
    * This is correct behavior for reading a series of images from one source.
    */
-  src->start_of_file = TRUE;
+  src->start_of_file = sal_True;
 }
 
 long StreamRead( SvStream* pSvStm, void* pBuffer, long nBufferSize )
@@ -238,9 +237,9 @@ extern "C" int fill_input_buffer (j_decompress_ptr cinfo)
 
   src->pub.next_input_byte = src->buffer;
   src->pub.bytes_in_buffer = nbytes;
-  src->start_of_file = FALSE;
+  src->start_of_file = sal_False;
 
-  return TRUE;
+  return sal_True;
 }
 
 extern "C" void skip_input_data (j_decompress_ptr cinfo, long num_bytes)
@@ -255,7 +254,7 @@ extern "C" void skip_input_data (j_decompress_ptr cinfo, long num_bytes)
     while (num_bytes > (long) src->pub.bytes_in_buffer) {
       num_bytes -= (long) src->pub.bytes_in_buffer;
       (void) fill_input_buffer(cinfo);
-      /* note we assume that fill_input_buffer will never return FALSE,
+      /* note we assume that fill_input_buffer will never return sal_False,
        * so suspension need not be handled.
        */
     }
@@ -335,24 +334,33 @@ JPEGReader::~JPEGReader()
 
 // ------------------------------------------------------------------------
 
-void* JPEGReader::CreateBitmap( void* pParam )
+void* JPEGReader::CreateBitmap( void* _pParam )
 {
-    Size        aSize( ((JPEGCreateBitmapParam*)pParam)->nWidth,
-                        ((JPEGCreateBitmapParam*)pParam)->nHeight );
-    sal_Bool    bGray = ((JPEGCreateBitmapParam*)pParam)->bGray != 0;
+    JPEGCreateBitmapParam *pParam = (JPEGCreateBitmapParam *) _pParam;
+
+    if (pParam->nWidth > SAL_MAX_INT32/8 || pParam->nHeight > SAL_MAX_INT32/8)
+        return NULL; // avoid overflows later
+
+    Size        aSize( pParam->nWidth, pParam->nHeight );
+    sal_Bool    bGray = pParam->bGray != 0;
 
     void* pBmpBuf = NULL;
 
     if( pAcc )
         aBmp.ReleaseAccess( pAcc );
 
+    sal_uInt64 nSize = aSize.Width();
+    nSize *= aSize.Height();
+    if (nSize > SAL_MAX_INT32 / 24)
+        return NULL;
+
     if( bGray )
     {
         BitmapPalette aGrayPal( 256 );
 
-        for( USHORT n = 0; n < 256; n++ )
+        for( sal_uInt16 n = 0; n < 256; n++ )
         {
-            const BYTE cGray = (BYTE) n;
+            const sal_uInt8 cGray = (sal_uInt8) n;
             aGrayPal[ n ] = BitmapColor( cGray, cGray, cGray );
         }
 
@@ -366,12 +374,11 @@ void* JPEGReader::CreateBitmap( void* pParam )
         unsigned long nUnit = ((JPEGCreateBitmapParam*)pParam)->density_unit;
         
         if( ( ( 1 == nUnit ) || ( 2 == nUnit ) ) && 
-            ( (JPEGCreateBitmapParam*) pParam )->X_density && 
-            ( (JPEGCreateBitmapParam*) pParam )->Y_density )
+            pParam->X_density && pParam->Y_density )
         {
             Point       aEmptyPoint;
-            Fraction	aFractX( 1, ((JPEGCreateBitmapParam*)pParam)->X_density );
-            Fraction	aFractY( 1, ((JPEGCreateBitmapParam*)pParam)->Y_density );
+            Fraction    aFractX( 1, pParam->X_density );
+            Fraction    aFractY( 1, pParam->Y_density );
             MapMode		aMapMode( nUnit == 1 ? MAP_INCH : MAP_CM, aEmptyPoint, aFractX, aFractY );
             Size		aPrefSize = OutputDevice::LogicToLogic( aSize, aMapMode, MAP_100TH_MM );
 
@@ -384,9 +391,7 @@ void* JPEGReader::CreateBitmap( void* pParam )
 
     if( pAcc )
     {
-        long nAlignedWidth;
-
-        const ULONG nFormat = pAcc->GetScanlineFormat();
+        const sal_uLong nFormat = pAcc->GetScanlineFormat();
 
         if(
             ( bGray && ( BMP_FORMAT_8BIT_PAL == nFormat ) ) ||
@@ -394,16 +399,15 @@ void* JPEGReader::CreateBitmap( void* pParam )
           )
         {
             pBmpBuf = pAcc->GetBuffer();
-            nAlignedWidth = pAcc->GetScanlineSize();
-            ((JPEGCreateBitmapParam*)pParam)->bTopDown = pAcc->IsTopDown();
+            pParam->nAlignedWidth = pAcc->GetScanlineSize();
+            pParam->bTopDown = pAcc->IsTopDown();
         }
         else
         {
-            nAlignedWidth = AlignedWidth4Bytes( aSize.Width() * ( bGray ? 8 : 24 ) );
-            ((JPEGCreateBitmapParam*)pParam)->bTopDown = TRUE;
-            pBmpBuf = pBuffer = rtl_allocateMemory( nAlignedWidth * aSize.Height() );
+            pParam->nAlignedWidth = AlignedWidth4Bytes( aSize.Width() * ( bGray ? 8 : 24 ) );
+            pParam->bTopDown = sal_True;
+            pBmpBuf = pBuffer = rtl_allocateMemory( pParam->nAlignedWidth * aSize.Height() );
         }
-        ((JPEGCreateBitmapParam*)pParam)->nAlignedWidth = nAlignedWidth;
     }
 
     return pBmpBuf;
@@ -425,9 +429,9 @@ void JPEGReader::FillBitmap()
         {
             BitmapColor* pCols = new BitmapColor[ 256 ];
 
-            for( USHORT n = 0; n < 256; n++ )
+            for( sal_uInt16 n = 0; n < 256; n++ )
             {
-                const BYTE cGray = (BYTE) n;
+                const sal_uInt8 cGray = (sal_uInt8) n;
                 pCols[ n ] = pAcc->GetBestMatchingColor( BitmapColor( cGray, cGray, cGray ) );
             }
 
@@ -435,7 +439,7 @@ void JPEGReader::FillBitmap()
 
             for( long nY = 0L; nY < nHeight; nY++ )
             {
-                pTmp = (BYTE*) pBuffer + nY * nAlignedWidth;
+                pTmp = (sal_uInt8*) pBuffer + nY * nAlignedWidth;
 
                 for( long nX = 0L; nX < nWidth; nX++ )
                     pAcc->SetPixel( nY, nX, pCols[ *pTmp++ ] );
@@ -449,7 +453,7 @@ void JPEGReader::FillBitmap()
 
             for( long nY = 0L; nY < nHeight; nY++ )
             {
-                pTmp = (BYTE*) pBuffer + nY * nAlignedWidth;
+                pTmp = (sal_uInt8*) pBuffer + nY * nAlignedWidth;
 
                 for( long nX = 0L; nX < nWidth; nX++ )
                 {
@@ -515,8 +519,8 @@ ReadState JPEGReader::Read( Graphic& rGraphic )
     long		nEndPos;
     long		nLines;
     ReadState	eReadState;
-    BOOL		bRet = FALSE;
-    BYTE		cDummy;
+    sal_Bool		bRet = sal_False;
+    sal_uInt8		cDummy;
 
 #if 1 // TODO: is it possible to get rid of this seek to the end?
     // check if the stream's end is already available
@@ -562,10 +566,10 @@ ReadState JPEGReader::Read( Graphic& rGraphic )
         else
             rGraphic = aBmp;
 
-        bRet = TRUE;
+        bRet = sal_True;
     }
     else if( rIStm.GetError() == ERRCODE_IO_PENDING )
-        bRet = TRUE;
+        bRet = sal_True;
 
     // Status setzen ( Pending hat immer Vorrang )
     if( rIStm.GetError() == ERRCODE_IO_PENDING )
@@ -629,13 +633,13 @@ void* JPEGWriter::GetScanline( long nY )
         {
             BitmapColor aColor;
             long		nWidth = pAcc->Width();
-            BYTE*		pTmp = pBuffer;
+            sal_uInt8*		pTmp = pBuffer;
 
             if( pAcc->HasPalette() )
             {
                 for( long nX = 0L; nX < nWidth; nX++ )
                 {
-                    aColor = pAcc->GetPaletteColor( (BYTE) pAcc->GetPixel( nY, nX ) );
+                    aColor = pAcc->GetPaletteColor( (sal_uInt8) pAcc->GetPixel( nY, nX ) );
                     *pTmp++ = aColor.GetRed();
                     if ( bGreys )
                         continue;
@@ -665,9 +669,9 @@ void* JPEGWriter::GetScanline( long nY )
 
 // ------------------------------------------------------------------------
 
-BOOL JPEGWriter::Write( const Graphic& rGraphic )
+sal_Bool JPEGWriter::Write( const Graphic& rGraphic )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if ( xStatusIndicator.is() )
     {
@@ -696,7 +700,7 @@ BOOL JPEGWriter::Write( const Graphic& rGraphic )
             BitmapColor aColor;
             for( long nX = 0L; bIsGrey && ( nX < nWidth ); nX++ )
             {
-                aColor = pAcc->HasPalette() ? pAcc->GetPaletteColor( (BYTE) pAcc->GetPixel( nY, nX ) )
+                aColor = pAcc->HasPalette() ? pAcc->GetPaletteColor( (sal_uInt8) pAcc->GetPixel( nY, nX ) )
                                             : pAcc->GetPixel( nY, nX );
                 bIsGrey = ( aColor.GetRed() == aColor.GetGreen() ) && ( aColor.GetRed() == aColor.GetBlue() );
             }
@@ -713,11 +717,11 @@ BOOL JPEGWriter::Write( const Graphic& rGraphic )
         bNative = ( pAcc->GetScanlineFormat() == BMP_FORMAT_24BIT_TC_RGB );
 
         if( !bNative )
-            pBuffer = new BYTE[ AlignedWidth4Bytes( bGreys ? pAcc->Width() * 8L : pAcc->Width() * 24L ) ];
+            pBuffer = new sal_uInt8[ AlignedWidth4Bytes( bGreys ? pAcc->Width() * 8L : pAcc->Width() * 24L ) ];
 
         JPEGCallbackStruct aCallbackData;
         aCallbackData.xStatusIndicator = xStatusIndicator;
-        bRet = (BOOL) WriteJPEG( this, &rOStm, pAcc->Width(), pAcc->Height(), bGreys, nQuality, &aCallbackData );
+        bRet = (sal_Bool) WriteJPEG( this, &rOStm, pAcc->Width(), pAcc->Height(), bGreys, nQuality, &aCallbackData );
 
         delete[] pBuffer;
         pBuffer = NULL;
@@ -735,11 +739,11 @@ BOOL JPEGWriter::Write( const Graphic& rGraphic )
 // - ImportJPEG -
 // --------------
 
-BOOL ImportJPEG( SvStream& rStm, Graphic& rGraphic, void* pCallerData, sal_Int32 nImportFlags )
+sal_Bool ImportJPEG( SvStream& rStm, Graphic& rGraphic, void* pCallerData, sal_Int32 nImportFlags )
 {
     JPEGReader*	pJPEGReader = (JPEGReader*) rGraphic.GetContext();
     ReadState	eReadState;
-    BOOL		bRet = TRUE;
+    sal_Bool		bRet = sal_True;
 
     if( !pJPEGReader )
         pJPEGReader = new JPEGReader( rStm, pCallerData, ( nImportFlags & GRFILTER_I_FLAGS_SET_LOGSIZE_FOR_JPEG ) != 0 );
@@ -754,7 +758,7 @@ BOOL ImportJPEG( SvStream& rStm, Graphic& rGraphic, void* pCallerData, sal_Int32
 
     if( eReadState == JPEGREAD_ERROR )
     {
-        bRet = FALSE;
+        bRet = sal_False;
         delete pJPEGReader;
     }
     else if( eReadState == JPEGREAD_OK )
@@ -769,7 +773,7 @@ BOOL ImportJPEG( SvStream& rStm, Graphic& rGraphic, void* pCallerData, sal_Int32
 //  - ExportJPEG -
 //  --------------
 
-BOOL ExportJPEG( SvStream& rOStm, const Graphic& rGraphic,
+sal_Bool ExportJPEG( SvStream& rOStm, const Graphic& rGraphic,
                  const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >* pFilterData,
                  bool* pExportWasGrey
                 )
@@ -777,3 +781,5 @@ BOOL ExportJPEG( SvStream& rOStm, const Graphic& rGraphic,
     JPEGWriter aJPEGWriter( rOStm, pFilterData, pExportWasGrey );
     return aJPEGWriter.Write( rGraphic );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
