@@ -287,7 +287,7 @@
     return AquaSalInstance::GetDynamicDockMenu();
 }
 
--(MacOSBOOL)application: (NSApplication*)app openFile: (NSString*)pFile
+-(BOOL)application: (NSApplication*)app openFile: (NSString*)pFile
 {
     const rtl::OUString aFile( GetOUString( pFile ) );
     if( ! AquaSalInstance::isOnCommandLine( aFile ) )
@@ -328,7 +328,7 @@
     }
 }
 
--(MacOSBOOL)application: (NSApplication*)app printFile: (NSString*)pFile
+-(BOOL)application: (NSApplication*)app printFile: (NSString*)pFile
 {
     const rtl::OUString aFile( GetOUString( pFile ) );
 	const ApplicationEvent* pAppEvent = new ApplicationEvent( String(), ApplicationAddress(),
@@ -336,7 +336,7 @@
 	AquaSalInstance::aAppEventList.push_back( pAppEvent );
     return YES;
 }
--(NSApplicationPrintReply)application: (NSApplication *) app printFiles:(NSArray *)files withSettings: (NSDictionary *)printSettings showPrintPanels:(MacOSBOOL)bShowPrintPanels
+-(NSApplicationPrintReply)application: (NSApplication *) app printFiles:(NSArray *)files withSettings: (NSDictionary *)printSettings showPrintPanels:(BOOL)bShowPrintPanels
 {
     // currently ignores print settings an bShowPrintPanels
     rtl::OUStringBuffer aFileList( 256 );
@@ -360,70 +360,35 @@
 
 -(NSApplicationTerminateReply)applicationShouldTerminate: (NSApplication *) app
 {
-    SalData* pSalData = GetSalData();
-    #if 1 // currently do some really bad hack
-    if( ! pSalData->maFrames.empty() )
+    NSApplicationTerminateReply aReply = NSTerminateNow;
     {
-        /* #i92766# something really weird is going on with the retain count of
-           our windows; sometimes we get a duplicate free before exit on one of our
-           NSWindows. The reason is unclear; to avoid this currently we retain them once more
-           
-           FIXME: this is a really bad hack, relying on the system to catch the leaked
-           resources. Find out what really goes on here and fix it !
-        */
-        std::vector< NSWindow* > aHackRetainedWindows;
-        for( std::list< AquaSalFrame* >::iterator it = pSalData->maFrames.begin();
-             it != pSalData->maFrames.end(); ++it )
+        YIELD_GUARD;
+        
+        SalData* pSalData = GetSalData();
+        if( ! pSalData->maFrames.empty() )
         {
-            #if OSL_DEBUG_LEVEL > 1
-            Window* pWin = (*it)->GetWindow();
-            String aTitle = pWin->GetText();
-            Window* pClient = pWin->ImplGetClientWindow();
-            fprintf( stderr, "retaining %p (old count %d) windowtype=%s clienttyp=%s title=%s\n",
-                (*it)->mpWindow, [(*it)->mpWindow retainCount],
-                typeid(*pWin).name(), pClient ? typeid(*pClient).name() : "<nil>",
-                rtl::OUStringToOString( aTitle, RTL_TEXTENCODING_UTF8 ).getStr()
-                );
-            #endif
-            [(*it)->mpWindow retain];
-            aHackRetainedWindows.push_back( (*it)->mpWindow ); 
+            // the following QueryExit will likely present a message box, activate application
+            [NSApp activateIgnoringOtherApps: YES];
+            aReply = pSalData->maFrames.front()->CallCallback( SALEVENT_SHUTDOWN, NULL ) ? NSTerminateCancel : NSTerminateNow;
         }
-        if( pSalData->maFrames.front()->CallCallback( SALEVENT_SHUTDOWN, NULL ) )
+        
+        if( aReply == NSTerminateNow )
         {
-            for( std::vector< NSWindow* >::iterator it = aHackRetainedWindows.begin();
-                 it != aHackRetainedWindows.end(); ++it )
-            {
-                // clean up the retaing count again from the shutdown workaround
-                #if OSL_DEBUG_LEVEL > 1
-                fprintf( stderr, "releasing %p\n", (*it) );
-                #endif
-                [(*it) release];
-            }
-            return NSTerminateCancel;
+            ApplicationEvent aEv( String(), ApplicationAddress(), ByteString( "PRIVATE:DOSHUTDOWN" ), String() );
+            GetpApp()->AppEvent( aEv );
+            ImplImageTreeSingletonRef()->shutDown();
+            // DeInitVCL should be called in ImplSVMain - unless someon _exits first which
+            // can occur in Desktop::doShutdown for example
         }
-        #if OSL_DEBUG_LEVEL > 1
-        for( std::list< AquaSalFrame* >::iterator it = pSalData->maFrames.begin();
-             it != pSalData->maFrames.end(); ++it )
-        {
-            Window* pWin = (*it)->GetWindow();
-            String aTitle = pWin->GetText();
-            Window* pClient = pWin->ImplGetClientWindow();
-            fprintf( stderr, "frame still alive: NSWindow %p windowtype=%s clienttyp=%s title=%s\n",
-                (*it)->mpWindow, typeid(*pWin).name(), pClient ? typeid(*pClient).name() : "<nil>",
-                rtl::OUStringToOString( aTitle, RTL_TEXTENCODING_UTF8 ).getStr()
-                );
-        }
-        #endif
     }
-    #else // the clean version follows
-    return pSalData->maFrames.front()->CallCallback( SALEVENT_SHUTDOWN, NULL ) ? NSTerminateCancel : NSTerminateNow;
-    #endif
-    ImplImageTreeSingletonRef()->shutDown();
-    return NSTerminateNow;
+    
+    return aReply;
 }
 
 -(void)systemColorsChanged: (NSNotification*) pNotification
 {
+    YIELD_GUARD;
+    
     const SalData* pSalData = GetSalData();
 	if( !pSalData->maFrames.empty() )
 		pSalData->maFrames.front()->CallCallback( SALEVENT_SETTINGSCHANGED, NULL );
@@ -431,6 +396,8 @@
 
 -(void)screenParametersChanged: (NSNotification*) pNotification
 {
+    YIELD_GUARD;
+    
     SalData* pSalData = GetSalData();
     std::list< AquaSalFrame* >::iterator it;
     for( it = pSalData->maFrames.begin(); it != pSalData->maFrames.end(); ++it )
@@ -501,7 +468,7 @@
     }
 }
 
-- (MacOSBOOL)applicationShouldHandleReopen: (NSApplication*)pApp hasVisibleWindows: (MacOSBOOL) bWinVisible
+- (BOOL)applicationShouldHandleReopen: (NSApplication*)pApp hasVisibleWindows: (BOOL) bWinVisible
 {
     NSObject* pHdl = GetSalData()->mpDockIconClickHandler;
     if( pHdl && [pHdl respondsToSelector: @selector(dockIconClicked:)] )
